.. currentmodule:: sardana.tango.pool.PoolDevice

:mod:`~sardana.tango.pool.PoolDevice`
==============================================

.. automodule:: sardana.tango.pool.PoolDevice

.. rubric:: Classes

.. hlist::
    :columns: 3

    * :class:`PoolDevice`
    * :class:`PoolDeviceClass`
    * :class:`PoolElementDevice`
    * :class:`PoolElementDeviceClass`
    * :class:`PoolGroupDevice`
    * :class:`PoolGroupDeviceClass`

PoolDevice
--------------

.. inheritance-diagram:: PoolDevice
    :parts: 1
    
.. autoclass:: PoolDevice
    :show-inheritance:
    :members:
    :undoc-members:

PoolDeviceClass
-------------------

.. inheritance-diagram:: PoolDeviceClass
    :parts: 1
    
.. autoclass:: PoolDeviceClass
    :show-inheritance:
    :members:
    :undoc-members:

PoolElementDevice
------------------

.. inheritance-diagram:: PoolElementDevice
    :parts: 1
    
.. autoclass:: PoolElementDevice
    :show-inheritance:
    :members:
    :undoc-members:

PoolElementDeviceClass
-------------------------

.. inheritance-diagram:: PoolElementDeviceClass
    :parts: 1
    
.. autoclass:: PoolElementDeviceClass
    :show-inheritance:
    :members:
    :undoc-members:

PoolGroupDevice
-----------------

.. inheritance-diagram:: PoolGroupDevice
    :parts: 1
    
.. autoclass:: PoolGroupDevice
    :show-inheritance:
    :members:
    :undoc-members:

PoolGroupDeviceClass
---------------------

.. inheritance-diagram:: PoolGroupDeviceClass
    :parts: 1
    
.. autoclass:: PoolGroupDeviceClass
    :show-inheritance:
    :members:
    :undoc-members:
